/* This handles the transforming of links to
  popover and ajax loading of the bibliography
    via the popvers
*/
/* initialize all popover which have an element data-toggle="popover" */

$(function () {

  $(document).on('click', function (e) {
    var
      $popover,
      $target = $(e.target);

    //do nothing if there was a click on popover content
    if ($target.hasClass('popover') || $target.closest('.popover').length) {
      return;
    }

    $('[data-toggle="popover"]').each(function () {
      $popover = $(this);

      if (!$popover.is(e.target) &&
        $popover.has(e.target).length === 0 &&
        $('.popover').has(e.target).length === 0) {
        $popover.popover('hide');
      } else {
        //fixes issue described above
        $popover.popover('toggle');
      }
    });
  })

});


/* handle the zotero bib popover click action */
$('.kmg-bib').click(function () {
  var e = $(this);
  if (e.data('loaded') !== true) {
    var multiple = false;
    var id = e.data('id');
    var ida = id.split(' ');
    var apiurl = null;
    if (ida.length == 1) {
      apiurl = "/exist/restxq/zotero/item/" + id;
    } else {
      apiurl = "/exist/restxq/zotero/items/" + ida.join(',');
      multiple = true;
    }
    $.ajax({
      url: apiurl,
      dataType: 'json',
      success: function (data) {
        e.data('loaded', true);
        var content = "";
        if (!multiple) {
          content = data.bib;
        } else {
          for (var key of Object.keys(data)) {
            content += data[key].bib;
          }
        }
        /* check if there is an additional Mollenhauer source entry and display it first
        then additional data from zotero */
        if (e.context.children[1].innerHTML != null && e.context.children[1].innerHTML != "") {
          e.attr('data-content', "<div class='zotero-content'>" + content + "</div><div class='zotero-suffix'>" + e.context.children[1].innerHTML + '</div>');
        } else {
          /* just add the zotero data */
          e.attr('data-content', "<div class='zotero-content'>" + content + '</div>');
        }
        var popover = e.data('bs.popover');
        popover.setContent();
        popover.$tip.addClass(popover.options.placement);
        var calculated_offset = popover.getCalculatedOffset(popover.options.placement, popover.getPosition(), popover.$tip[0].offsetWidth, popover.$tip[0].offsetHeight);
        popover.applyPlacement(calculated_offset, popover.options.placement);
      },
      error: function (jqXHR, textStatus, errorThrown) {
        e.attr('data-content', 'Daten konten nicht geladen werden');
        var popover = e.data('bs.popover');
        popover.setContent();
      }
    });
  }
});

$('.kmg-pnd').click(function () {
  var e = $(this);
  if (e.data('loaded') !== true) {
    var id = e.data('id') + '';
    var ids = id.split(' ');
    var content = "";
    var deferreds = [];
    $.each(ids, function (index, pndid) {
      deferreds.push(
        $.get('https://ref.de.dariah.eu/pndsearch/json?id=' + pndid, function (res) {
          content += renderGNDData(res, pndid);
        })
      );
    });
    $.when.apply($, deferreds).then(function () {
      e.data('loaded', true);
      e.attr('data-content', content);

      var popover = e.data('bs.popover');
      popover.setContent();
      popover.$tip.addClass(popover.options.placement);
      var calculated_offset = popover.getCalculatedOffset(popover.options.placement, popover.getPosition(), popover.$tip[0].offsetWidth, popover.$tip[0].offsetHeight);
      popover.applyPlacement(calculated_offset, popover.options.placement);
    }).fail(function () {
      e.attr('data-content', 'Daten konten nicht geladen werden');
      var popover = e.data('bs.popover');
      popover.setContent();
    });

  }

});

function renderGNDData(data, id) {
  var html = '<div class="gnd-table">'

  html += renderGNDDataRow('Name:', data.entry.preferredNameForThePerson);
  if (data.entry.si != null && Array.isArray(data.entry.si)) {
    var alternateNames = "";
    for (i = 1; i < data.entry.si.length; i++) {
      if (i == 4) {
        alternateNames += "[...]"
        break;
      }
      alternateNames += data.entry.si[i] + "<br/>";
    }
    html += renderGNDDataRow('Andere Namen:', alternateNames);
  }
  if (data.entry.variantNameForThePerson != null && Array.isArray(data.entry.variantNameForThePerson)) {
    var variants = "";
    for (i = 1; i < data.entry.variantNameForThePerson.length; i++) {
      if (i == 4) {
        variants += "[...]"
        break;
      }
      variants += data.entry.variantNameForThePerson[i] + "<br/>";
    }
    html += renderGNDDataRow('Varianten:', variants);
  }

  html += renderGNDDataRow('Weitere Angaben:', data.entry.biographicalInformation);
  html += renderGNDDataRow('Räumlicher Bezug:', data.entry.placeOfResidence);
  html += renderGNDDataRow('Geburtsdatum:', formatDate(data.entry.dateOfBirth));
  html += renderGNDDataRow('Geburtsort:', data.entry.placeOfBirth);
  html += renderGNDDataRow('Sterbedatum:', formatDate(data.entry.dateOfDeath));
  html += renderGNDDataRow('Sterbeort:', data.entry.placeOfDeath);
  html += renderGNDDataRow('GND Eintrag:', '<a href="http://d-nb.info/gnd/' + id + '"><i class="fas fa-external-link-alt"></i> ' + id + '</a>');

  html += '</div>'
  return html;

}

$('.kmg-dnb').click(function () {
  var e = $(this);
  if (e.data('loaded') !== true) {
    var id = e.data('id') + '';
    var ids = id.split(' ');
    var content = "";
    var deferreds = [];
    $.each(ids, function (index, pndid) {
      deferreds.push(
        $.get('https://ref.de.dariah.eu/pndsearch/json?id=' + pndid, function (res) {
          content += renderDNBData(res, pndid);
        })
      );
    });
    $.when.apply($, deferreds).then(function () {
      e.data('loaded', true);
      e.attr('data-content', content);

      var popover = e.data('bs.popover');
      popover.setContent();
      popover.$tip.addClass(popover.options.placement);
      var calculated_offset = popover.getCalculatedOffset(popover.options.placement, popover.getPosition(), popover.$tip[0].offsetWidth, popover.$tip[0].offsetHeight);
      popover.applyPlacement(calculated_offset, popover.options.placement);
    }).fail(function () {
      e.attr('data-content', 'Daten konten nicht geladen werden');
      var popover = e.data('bs.popover');
      popover.setContent();
    });

  }

});

function renderDNBData(data, id) {
  var html = '<div class="gnd-table">'

  html += renderGNDDataRow('Name:', data.entry.preferredNameForThePerson);
  if (data.entry.si != null && Array.isArray(data.entry.si)) {
    var alternateNames = "";
    for (i = 1; i < data.entry.si.length; i++) {
      if (i == 4) {
        alternateNames += "[...]"
        break;
      }
      alternateNames += data.entry.si[i] + "<br/>";
    }
    html += renderGNDDataRow('Andere Namen:', alternateNames);
  }
  if (data.entry.variantNameForThePerson != null && Array.isArray(data.entry.variantNameForThePerson)) {
    var variants = "";
    for (i = 1; i < data.entry.variantNameForThePerson.length; i++) {
      if (i == 4) {
        variants += "[...]"
        break;
      }
      variants += data.entry.variantNameForThePerson[i] + "<br/>";
    }
    html += renderGNDDataRow('Varianten:', variants);
  }

  html += renderGNDDataRow('Weitere Angaben:', data.entry.biographicalInformation);
  html += renderGNDDataRow('Räumlicher Bezug:', data.entry.placeOfResidence);
  html += renderGNDDataRow('Geburtsdatum:', formatDate(data.entry.dateOfBirth));
  html += renderGNDDataRow('Geburtsort:', data.entry.placeOfBirth);
  html += renderGNDDataRow('Sterbedatum:', formatDate(data.entry.dateOfDeath));
  html += renderGNDDataRow('Sterbeort:', data.entry.placeOfDeath);
  html += renderGNDDataRow('DNB Eintrag:', '<a href="http://d-nb.info/' + id + '"><i class="fas fa-external-link-alt"></i> ' + id + '</a>');

  html += '</div>'
  return html;

}

function renderGNDDataRow(name, description) {
  var html = "";
  if (description != null) {
    html = '<div class="gnd-table-row">';
    html += '<div class="gnd-table-cell">';
    html += name;
    html += '</div>';
    html += '<div class="gnd-table-cell">';
    html += description;
    html += '</div>';
    html += '</div>';
  }
  return html;
}

function formatDate(date) {
  if (date == null)
    return null;
  /* before christ */
  if (date.startsWith('-'))
    return date;
  /* do not format year only */
  if (date.length == 4)
    return date;
  var fdate = "";
  var d = new Date(date);
  var day = d.getDate();
  if (day < 10)
    fdate = "0" + day + ".";
  else
    fdate = day + ".";
  var month = d.getMonth();
  month = month + 1;
  if (month < 10)
    fdate += "0" + month + ".";
  else
    fdate += month + ".";
  fdate += d.getFullYear();
  return fdate;
}

/* handle loading of lido information */
$('.kmg-art').click(function () {
  var e = $(this);
  if (e.data('loaded') !== true) {
    $.ajax({
      url: '/exist/apps/sade/textgrid/data/kmg-lido/' + e.data('id') + '.xml',
      dataType: 'html',
      success: function (data) {
        e.data('loaded', true);
        e.attr('data-content', data.replace(/\<(\?xml|(\!DOCTYPE[^\>\[]+(\[[^\]]+)?))+[^>]+\>/g, ''));
        var popover = e.data('bs.popover');
        popover.setContent();
        popover.$tip.addClass(popover.options.placement);
        var calculated_offset = popover.getCalculatedOffset(popover.options.placement, popover.getPosition(), popover.$tip[0].offsetWidth, popover.$tip[0].offsetHeight);
        popover.applyPlacement(calculated_offset, popover.options.placement);
      },
      error: function (jqXHR, textStatus, errorThrown) {
        e.attr('data-content', 'Daten konten nicht geladen werden');
        var popover = e.data('bs.popover');
        popover.setContent();
      }
    });
  }
});


$('a[href="#goto"]').click(function(){
    var id = parseInt(this.id);
    var scrollto = $(".headlabel:eq('"+id+"')");
    $("html, body").animate({
        scrollTop: scrollto.offset().top - 115
    }, 750);
});
